@@ -36,7 +36,7 @@ __all__ = [
 
 loc = locale.getlocale()
 if sys.version_info.major > 2:
-    if not loc[1] or 'UTF-8' not in loc[1]:
+    if not loc[1] or ('UTF-8' not in loc[1] and 'utf8' not in loc[1]):
         print('WARNING!!! You are running with a non-UTF8 locale environment '
               'variables (e.g. LC_ALL is set to "C"), which makes Python 3 do '
               'stupid things. If you get strange errors, please set it to '
