@@ -1,5 +1,5 @@
 # coding=utf-8
-from __future__ import unicode_literals, absolute_import, print_function, division
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import errno
 import json
@@ -8,14 +8,14 @@ import os.path
 import sys
 import traceback
 
-from sopel.tools import Identifier
-
-from sqlalchemy import create_engine, Column, ForeignKey, Integer, String
+from sqlalchemy import Column, create_engine, ForeignKey, Integer, String
 from sqlalchemy.engine.url import URL
 from sqlalchemy.exc import OperationalError, SQLAlchemyError
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import scoped_session, sessionmaker
 
+from sopel.tools import Identifier
+
 if sys.version_info.major >= 3:
     unicode = str
     basestring = str
@@ -437,6 +437,10 @@ class SopelDB(object):
                               set (optional)
         :raise ~sqlalchemy.exc.SQLAlchemyError: if there is a database error
 
+        .. versionadded:: 7.0
+
+            The ``default`` parameter.
+
         .. seealso::
 
             To set a value for later retrieval with this method, use
@@ -691,6 +695,10 @@ class SopelDB(object):
                               set (optional)
         :raise ~sqlalchemy.exc.SQLAlchemyError: if there is a database error
 
+        .. versionadded:: 7.0
+
+            The ``default`` parameter.
+
         .. seealso::
 
             To set a value for later retrieval with this method, use
@@ -805,6 +813,10 @@ class SopelDB(object):
                               set (optional)
         :raise ~sqlalchemy.exc.SQLAlchemyError: if there is a database error
 
+        .. versionadded:: 7.0
+
+            The ``default`` parameter.
+
         .. seealso::
 
             To set a value for later retrieval with this method, use
@@ -843,6 +855,10 @@ class SopelDB(object):
                               set (optional)
         :raise ~sqlalchemy.exc.SQLAlchemyError: if there is a database error
 
+        .. versionadded:: 7.0
+
+            The ``default`` parameter.
+
         This is useful for common logic that is shared between both users and
         channels, as it will fetch the appropriate value based on what type of
         ``name`` it is given.
