@@ -4,7 +4,7 @@
 # Licensed under the Eiffel Forum License 2.
 # When working on core IRC protocol related features, consult protocol
 # documentation at http://www.irchelp.org/irchelp/rfc/
-from __future__ import unicode_literals, absolute_import, print_function, division
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import asynchat
 import asyncore
@@ -14,9 +14,10 @@ import logging
 import os
 import socket
 import sys
-from threading import current_thread
+import threading
 
-from sopel.tools.jobs import JobScheduler, Job
+from sopel import loader, plugin
+from sopel.tools import jobs
 from .abstract_backends import AbstractIRCBackend
 from .utils import get_cnames
 
@@ -40,62 +41,123 @@ if sys.version_info.major >= 3:
 LOGGER = logging.getLogger(__name__)
 
 
+@plugin.thread(False)
+@plugin.interval(5)
 def _send_ping(backend):
-    if not backend.connected:
+    if not backend.is_connected():
         return
-    time_passed = (datetime.datetime.utcnow() - backend.last_event_at).seconds
-    if time_passed > backend.ping_timeout:
+
+    events = []
+    need_ping = True
+
+    # Ensure we have a time to check first
+    if backend.last_event_at:
+        events.append(backend.last_event_at)
+
+    if backend.last_ping_at:
+        events.append(backend.last_ping_at)
+
+    # At least a PING was sent, or a message was received
+    if events:
+        last_event = max(events)
+        dt = datetime.datetime.utcnow() - last_event
+        time_passed = dt.total_seconds()
+        need_ping = time_passed > backend.ping_interval
+
+    # Send PING only if needed
+    if need_ping:
         try:
             backend.send_ping(backend.host)
+            backend.last_ping_at = datetime.datetime.utcnow()
         except socket.error:
             LOGGER.exception('Socket error on PING')
 
 
+@plugin.thread(False)
+@plugin.interval(10)
 def _check_timeout(backend):
-    if not backend.connected:
+    if not backend.is_connected():
         return
-    time_passed = (datetime.datetime.utcnow() - backend.last_event_at).seconds
+    dt = datetime.datetime.utcnow() - backend.last_event_at
+    time_passed = dt.total_seconds()
     if time_passed > backend.server_timeout:
         LOGGER.error(
             'Server timeout detected after %ss; closing.', time_passed)
+        # discard buffers: no need to read/write anything more, just quit
+        LOGGER.debug('Discard current buffers.')
+        backend.discard_buffers()
+        # close now
         backend.handle_close()
 
 
-_send_ping.thread = False
-_check_timeout.thread = False
-
-
 class AsynchatBackend(AbstractIRCBackend, asynchat.async_chat):
     """IRC backend implementation using :mod:`asynchat` (:mod:`asyncore`).
 
     :param bot: a Sopel instance
     :type bot: :class:`sopel.bot.Sopel`
     :param int server_timeout: connection timeout in seconds
-    :param int ping_timeout: ping timeout in seconds
+    :param int ping_interval: ping interval in seconds
+
+    The ``server_timeout`` option defaults to ``120`` seconds if not provided.
+
+    The ``ping_interval`` defaults to ``server_timeout * 0.45`` if not specified.
     """
-    def __init__(self, bot, server_timeout=None, ping_timeout=None, **kwargs):
+    def __init__(self, bot, server_timeout=None, ping_interval=None, **kwargs):
         AbstractIRCBackend.__init__(self, bot)
         asynchat.async_chat.__init__(self)
+        self.writing_lock = threading.RLock()
         self.set_terminator(b'\n')
         self.buffer = ''
         self.server_timeout = server_timeout or 120
-        self.ping_timeout = ping_timeout or (self.server_timeout / 2)
+        self.ping_interval = ping_interval or (self.server_timeout * 0.45)
         self.last_event_at = None
+        self.last_ping_at = None
         self.host = None
         self.port = None
         self.source_address = None
+        self.timeout_scheduler = jobs.Scheduler(self)
 
-        ping_job = Job(self.ping_timeout, _send_ping)
-        timeout_job = Job(self.server_timeout, _check_timeout)
+        # register timeout jobs
+        self.register_timeout_jobs([
+            _send_ping,
+            _check_timeout,
+        ])
 
-        self.timeout_scheduler = JobScheduler(self)
-        self.timeout_scheduler.add_job(ping_job)
-        self.timeout_scheduler.add_job(timeout_job)
+    def is_connected(self):
+        return self.connected
+
+    def on_irc_error(self, pretrigger):
+        if self.bot.hasquit:
+            # discard buffers: no need to read/write anything more, just quit
+            LOGGER.debug('Discard current buffers.')
+            self.discard_buffers()
+            # close now
+            self.handle_close()
+
+    def irc_send(self, data):
+        """Send an IRC line as raw ``data`` to the socket connection.
+
+        :param bytes data: raw line to send
+
+        This uses :meth:`asyncore.dispatcher.send` method to send ``data``
+        directly. This method is thread-safe.
+        """
+        with self.writing_lock:
+            self.send(data)
 
     def run_forever(self):
         """Run forever."""
+        LOGGER.debug('Running forever.')
         asyncore.loop()
 
+    def register_timeout_jobs(self, handlers):
+        """Register the timeout handlers for the timeout scheduler."""
+        for handler in handlers:
+            loader.clean_callable(handler, self.bot.settings)
+            job = jobs.Job.from_callable(self.bot.settings, handler)
+            self.timeout_scheduler.register(job)
+            LOGGER.debug('Timeout Job registered: %s', str(job))
+
     def initiate_connect(self, host, port, source_address):
         """Initiate IRC connection.
 
@@ -126,22 +188,20 @@ class AsynchatBackend(AbstractIRCBackend, asynchat.async_chat):
         self.bot.on_connect()
 
     def handle_close(self):
-        """Called when the socket is closed."""
+        """Called when the connection must be closed."""
+        LOGGER.debug('Stopping timeout watchdog')
         self.timeout_scheduler.stop()
-        if current_thread() is not self.timeout_scheduler:
-            self.timeout_scheduler.join(timeout=15)
-
-        LOGGER.info('Connection closed...')
-        try:
-            self.bot.on_close()
-        finally:
-            if self.socket:
-                LOGGER.debug('Closing socket')
-                self.close()
-                LOGGER.info('Closed!')
+        LOGGER.info('Closing connection')
+        self.close()
+        self.bot.on_close()
 
     def handle_error(self):
-        """Called when an exception is raised and not otherwise handled."""
+        """Called when an exception is raised and not otherwise handled.
+
+        This method is an override of :meth:`asyncore.dispatcher.handle_error`,
+        the :class:`asynchat.async_chat` being a subclass of
+        :class:`asyncore.dispatcher`.
+        """
         LOGGER.info('Connection error...')
         self.bot.on_error()
 
